/****************************************************************************
// Name:        dfttsval.h
// Purpose:     
// Author:     Digital Future
// Modified by: 
// Created:     07/15/2008
// RCS-ID:      
// Copyright:   (C) Digital Future. All rights reserved.
// Licence:     
***************************************************************************/

#ifndef _DFTTS_VAL_H_
#define _DFTTS_VAL_H_

#include "dfttslang.h"

#define NUM_ENGINE_INITIALIZATIONS 16

#define NEOSPEECH_NUM_VOICES 12

typedef enum DFTTSPredefinedSpeechParams
{
	DF_TTS_DEFAULT_PITCH = 100, /*100%*/
	DF_TTS_DEFAULT_SPEED = 100, /*100%*/
	DF_TTS_DEFAULT_VOLUME = 100, /*100%*/
	DF_TTS_DEFAULT_PAUSE = 670, /*670 msec*/
	DF_TTS_NEOSPEECH_MIN_PITCH = 50,
	DF_TTS_NEOSPEECH_MAX_PITCH = 200,
	DF_TTS_NEOSPEECH_MIN_SPEED = 50,
	DF_TTS_NEOSPEECH_MAX_SPEED = 400,
	DF_TTS_NEOSPEECH_MIN_VOLUME = 0,
	DF_TTS_NEOSPEECH_MAX_VOLUME = 500,
	DF_TTS_NEOSPEECH_MIN_PAUSE = 0,
	DF_TTS_NEOSPEECH_MAX_PAUSE = 20000,
	DF_TTS_CEPSTRAL_MIN_PITCH = 100,
	DF_TTS_CEPSTRAL_MAX_PITCH = 500,
	DF_TTS_CEPSTRAL_MIN_SPEED = 0,
	DF_TTS_CEPSTRAL_MAX_SPEED = 400,
	DF_TTS_CEPSTRAL_MIN_VOLUME = 0,
	DF_TTS_CEPSTRAL_MAX_VOLUME = 500,
	DF_TTS_ATTNV_MIN_SPEED = 13,
	DF_TTS_ATTNV_MAX_SPEED = 800,
	DF_TTS_ATTNV_MIN_VOLUME = 0,
	DF_TTS_ATTNV_MAX_VOLUME = 500,
	DF_TTS_ATTNV_MIN_PITCH = 0, /*AT&T NV do not support this*/
	DF_TTS_ATTNV_MAX_PITCH = 0, /*AT&T NV do not support this*/
	DF_TTS_MACOSXSPMAN_MIN_PITCH = 1,
	DF_TTS_MACOSXSPMAN_MAX_PITCH = 1000,
	DF_TTS_MACOSXSPMAN_MIN_SPEED = 1,
	DF_TTS_MACOSXSPMAN_MAX_SPEED = 1000,
	DF_TTS_MACOSXSPMAN_MIN_VOLUME = 100,
	DF_TTS_MACOSXSPMAN_MAX_VOLUME = 500,
	DF_TTS_MSSAPI_MIN_PITCH = 30,
	DF_TTS_MSSAPI_MAX_PITCH = 350,
	DF_TTS_MSSAPI_MIN_SPEED = 30,
	DF_TTS_MSSAPI_MAX_SPEED = 350,
	DF_TTS_MSSAPI_MIN_VOLUME = 0,
	DF_TTS_MSSAPI_MAX_VOLUME = 100	

} DFTTSPredefinedSpeechParams;	

	
typedef enum DFTTSVoiceEngineType
{
	NOENGINE = -4,
	ALLENGINES = -3,
	NEOSPEECHVOICETEXT = 0,
	CEPSTRAL,
	ATTNV,
	MSSAPI,
	MACOSXSPMAN
	
} DFTTSVoiceEngineType;


typedef enum InitDFTTSEngineReturnValue
{

	INIT_DFTTS_ENGINE_SUCCESS,
	INIT_DFTTS_ENGINE_ERROR_DB_PATH_DIFFERENT,
	INIT_DFTTS_ENGINE_ERROR_CHANNEL_MEM_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_MORPHEME_ANALYSIS_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_BREAK_INDEX_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_TEXT_PREP_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_ACOU_MODEL_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_UNIT_SEL_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_PROS_MODEL_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_SPEECH_DB_FAIL,
	INIT_DFTTS_ENGINE_ERROR_DB_PITCH_LOC_INFO_FAIL,
	INIT_DFTTS_ENGINE_ERROR_FAILED,
	INIT_DFTTS_ENGINE_ERROR_INVALIDARG,
	INIT_DFTTS_ENGINE_ERROR_OUTOFMEMORY,
	INIT_DFTTS_ENGINE_ERROR_NOTIMPL,
	INIT_DFTTS_ENGINE_ERROR_ABORT,
	INIT_DFTTS_ENGINE_ERROR_UNKNOWN,
	INIT_DFTTS_ENGINE_ERROR_BADHANDLE,
	INIT_DFTTS_ENGINE_ERROR_EXCEPTION,
	INIT_DFTTS_ENGINE_ERROR_EMPTY,
	INIT_DFTTS_ENGINE_ERROR_FULL,
	INIT_DFTTS_ENGINE_ERROR_INVALIDSTATE,
	INIT_DFTTS_ENGINE_ERROR_BADVERSION,
	INIT_DFTTS_ENGINE_ERROR_INSUFFICIENT_BUFFER,
	INIT_DFTTS_ENGINE_ERROR_UNSUPPORTED,
	INIT_DFTTS_ENGINE_ERROR_NOLICENSE,
	INIT_DFTTS_ENGINE_ERROR_CREATECHILDPROCESS_FAILED,
	INIT_DFTTS_ENGINE_ERROR_NOENVIRONMENTPATH,
	INIT_DFTTS_ENGINE_ERROR_TIMEOUT,
	INIT_DFTTS_ENGINE_ERROR_OUTOFRESOURCES,
	INIT_DFTTS_ENGINE_ERROR_NOVOICES,
	INIT_DFTTS_ENGINE_ERROR_CREATEFAIL,
	INIT_DFTTS_ENGINE_ERROR_CONNECTFAIL,
	INIT_DFTTS_ENGINE_ERROR_BINDFAIL,
	INIT_DFTTS_ENGINE_ERROR_LISTENFAIL,
	INIT_DFTTS_ENGINE_ERROR_CONNECTIONCLOSED,
	INIT_DFTTS_ENGINE_ERROR_ACCEPTFAIL,
	INIT_DFTTS_ENGINE_ERROR_SOCKETTIMEOUT,
	INIT_DFTTS_ENGINE_ERROR_SOCKETERROR,
	INIT_DFTTS_ENGINE_ERROR_NOMORESERVERS,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EWOULDBLOCK,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EINPROGRESS,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EALREADY,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENOTSOCK,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EDESTADDRREQ,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EMSGSIZE,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EPROTOTYPE,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENOPROTOOPT,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EPROTONOSUPPORT,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ESOCKTNOSUPPORT,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EOPNOTSUPP,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EPFNOSUPPORT,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EAFNOSUPPORT,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EADDRINUSE,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EADDRNOTAVAIL,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENETDOWN,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENETUNREACH,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENETRESET,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ECONNABORTED,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ECONNRESET,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENOBUFS,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EISCONN,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENOTCONN,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ESHUTDOWN,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ETOOMANYREFS,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ECONNREFUSED,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ELOOP,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENAMETOOLONG,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EHOSTDOWN,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EHOSTUNREACH,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_ENOTEMPTY,
	INIT_DFTTS_ENGINE_ERROR_SOCKET_EPROCLIM,
	INIT_DFTTS_ENGINE_ERROR_THREADSTARTED,
	INIT_DFTTS_ENGINE_ERROR_THREADNOTSTARTED,
	INIT_DFTTS_ENGINE_ERROR_THREADCOULDNOTCREATE,
	INIT_DFTTS_ENGINE_ERROR_BADNVFILE,
	INIT_DFTTS_ENGINE_ERROR_NOAUDIODRIVER,
	INIT_DFTTS_ENGINE_ERROR_DICTNOTFOUND,
	INIT_DFTTS_ENGINE_ERROR_OTHER

} InitDFTTSEngineReturnValue;


typedef enum UninitDFTTSEngineReturnValue
{

	UNINIT_DFTTS_ENGINE_SUCCESS,
	UNINIT_DFTTS_ENGINE_FAIL

} UninitDFTTSEngineReturnValue;


typedef enum LoadDFTTSUserDictReturnValue
{

	LOAD_USER_DICT_SUCCESS,
	LOAD_USER_DICT_ERROR_DICTIDX_NOT_VALID,
	LOAD_USER_DICT_ERROR_DICT_ALREADY_LOADED,
	LOAD_USER_DICT_ERROR_DICT_WORD_ALREADY_LOADED,
	LOAD_USER_DICT_ERROR_NO_DICT_FILE_OR_ENTRY,
	LOAD_USER_DICT_ERROR_INVALID_DICT_FILE,
	LOAD_USER_DICT_ERROR_INVALID_VOICE,
	LOAD_USER_DICT_ERROR_INVALID_ARG,
	LOAD_USER_DICT_ERROR_INVALID_PHONEME_SET,
	LOAD_USER_DICT_ERROR_INVALID_PHONEME,
	LOAD_USER_DICT_ERROR_INVALID_PARTOFSP,
	LOAD_USER_DICT_ERROR_DENIED,
	LOAD_USER_DICT_ERROR_OUTOFMEMORY,
	LOAD_USER_DICT_ERROR_INTERNAL,
	LOAD_USER_DICT_ERROR_OTHER

} LoadDFTTSUserDictReturnValue;


typedef enum UnloadDFTTSUserDictReturnValue
{

	UNLOAD_USER_DICT_SUCCESS,
	UNLOAD_USER_DICT_ERROR_DICTIDX_NOT_VALID,
	UNLOAD_USER_DICT_ERROR_DICT_UNLOADED,
	UNLOAD_USER_DICT_ERROR_NO_DICT_FILE_OR_ENTRY,
	UNLOAD_USER_DICT_ERROR_INVALID_PARTOFSP,
	UNLOAD_USER_DICT_ERROR_INVALID_PHONEME_SET,
	UNLOAD_USER_DICT_ERROR_INTERNAL,
	UNLOAD_USER_DICT_ERROR_OTHER

} UnloadDFTTSUserDictReturnValue;


typedef enum DFTTSTextType
{
	DFTTS_TEXT_TYPE_PLAIN,
	DFTTS_TEXT_TYPE_XML

} DFTTSTextType;


typedef enum DFTTSSpeakReturnValue
{
	DFTTS_SPEAK_SUCCESS,
	DFTTS_SPEAK_ERROR_CHANNEL_MEM_FAIL,
	DFTTS_SPEAK_ERROR_TEXT_NULL,
	DFTTS_SPEAK_ERROR_TEXT_ZERO_LEN,
	DFTTS_SPEAK_ERROR_DB_NOT_LOADED,
	DFTTS_SPEAK_ERROR_SET_SOUND_CARD_FAIL,
	DFTTS_SPEAK_ERROR_UNIMPLEMENTED,
	DFTTS_SPEAK_ERROR_INTERNAL,
	DFTTS_SPEAK_ERROR_INVALID_PARAM,
	DFTTS_SPEAK_ERROR_INVALID_POINTER,
	DFTTS_SPEAK_ERROR_UNKNOWN_ENCODING,
	DFTTS_SPEAK_ERROR_OBJECT_NOT_FOUND,
	DFTTS_SPEAK_ERROR_INTERRUPTED,
	DFTTS_SPEAK_ERROR_INVALID_VOICE,
	DFTTS_SPEAK_ERROR_WRONG_EVENT,
	DFTTS_SPEAK_ERROR_ENGINE_INUSE,
	DFTTS_SPEAK_ERROR_NETWORK_ERROR,
	DFTTS_SPEAK_ERROR_INVALID_KEY,
	DFTTS_SPEAK_ERROR_QUEUE_FULL,
	DFTTS_SPEAK_ERROR_TOKEN_TIMEOUT,
	DFTTS_SPEAK_ERROR_FAILED,
	DFTTS_SPEAK_ERROR_INVALIDARG,
	DFTTS_SPEAK_ERROR_OUTOFMEMORY,
	DFTTS_SPEAK_ERROR_NOTIMPL,
	DFTTS_SPEAK_ERROR_ABORT,
	DFTTS_SPEAK_ERROR_UNKNOWN,
	DFTTS_SPEAK_ERROR_BADHANDLE,
	DFTTS_SPEAK_ERROR_EXCEPTION,
	DFTTS_SPEAK_ERROR_EMPTY,
	DFTTS_SPEAK_ERROR_FULL,
	DFTTS_SPEAK_ERROR_INVALIDSTATE,
	DFTTS_SPEAK_ERROR_BADVERSION,
	DFTTS_SPEAK_ERROR_INSUFFICIENT_BUFFER,
	DFTTS_SPEAK_ERROR_UNSUPPORTED,
	DFTTS_SPEAK_ERROR_NOLICENSE,
	DFTTS_SPEAK_ERROR_CREATECHILDPROCESS_FAILED,
	DFTTS_SPEAK_ERROR_NOENVIRONMENTPATH,
	DFTTS_SPEAK_ERROR_TIMEOUT,
	DFTTS_SPEAK_ERROR_OUTOFRESOURCES,
	DFTTS_SPEAK_ERROR_NOVOICES,
	DFTTS_SPEAK_ERROR_CREATEFAIL,
	DFTTS_SPEAK_ERROR_CONNECTFAIL,
	DFTTS_SPEAK_ERROR_BINDFAIL,
	DFTTS_SPEAK_ERROR_LISTENFAIL,
	DFTTS_SPEAK_ERROR_CONNECTIONCLOSED,
	DFTTS_SPEAK_ERROR_ACCEPTFAIL,
	DFTTS_SPEAK_ERROR_SOCKETTIMEOUT,
	DFTTS_SPEAK_ERROR_SOCKETERROR,
	DFTTS_SPEAK_ERROR_NOMORESERVERS,
	DFTTS_SPEAK_ERROR_SOCKET_EWOULDBLOCK,
	DFTTS_SPEAK_ERROR_SOCKET_EINPROGRESS,
	DFTTS_SPEAK_ERROR_SOCKET_EALREADY,
	DFTTS_SPEAK_ERROR_SOCKET_ENOTSOCK,
	DFTTS_SPEAK_ERROR_SOCKET_EDESTADDRREQ,
	DFTTS_SPEAK_ERROR_SOCKET_EMSGSIZE,
	DFTTS_SPEAK_ERROR_SOCKET_EPROTOTYPE,
	DFTTS_SPEAK_ERROR_SOCKET_ENOPROTOOPT,
	DFTTS_SPEAK_ERROR_SOCKET_EPROTONOSUPPORT,
	DFTTS_SPEAK_ERROR_SOCKET_ESOCKTNOSUPPORT,
	DFTTS_SPEAK_ERROR_SOCKET_EOPNOTSUPP,
	DFTTS_SPEAK_ERROR_SOCKET_EPFNOSUPPORT,
	DFTTS_SPEAK_ERROR_SOCKET_EAFNOSUPPORT,
	DFTTS_SPEAK_ERROR_SOCKET_EADDRINUSE,
	DFTTS_SPEAK_ERROR_SOCKET_EADDRNOTAVAIL,
	DFTTS_SPEAK_ERROR_SOCKET_ENETDOWN,
	DFTTS_SPEAK_ERROR_SOCKET_ENETUNREACH,
	DFTTS_SPEAK_ERROR_SOCKET_ENETRESET,
	DFTTS_SPEAK_ERROR_SOCKET_ECONNABORTED,
	DFTTS_SPEAK_ERROR_SOCKET_ECONNRESET,
	DFTTS_SPEAK_ERROR_SOCKET_ENOBUFS,
	DFTTS_SPEAK_ERROR_SOCKET_EISCONN,
	DFTTS_SPEAK_ERROR_SOCKET_ENOTCONN,
	DFTTS_SPEAK_ERROR_SOCKET_ESHUTDOWN,
	DFTTS_SPEAK_ERROR_SOCKET_ETOOMANYREFS,
	DFTTS_SPEAK_ERROR_SOCKET_ECONNREFUSED,
	DFTTS_SPEAK_ERROR_SOCKET_ELOOP,
	DFTTS_SPEAK_ERROR_SOCKET_ENAMETOOLONG,
	DFTTS_SPEAK_ERROR_SOCKET_EHOSTDOWN,
	DFTTS_SPEAK_ERROR_SOCKET_EHOSTUNREACH,
	DFTTS_SPEAK_ERROR_SOCKET_ENOTEMPTY,
	DFTTS_SPEAK_ERROR_SOCKET_EPROCLIM,
	DFTTS_SPEAK_ERROR_THREADSTARTED,
	DFTTS_SPEAK_ERROR_THREADNOTSTARTED,
	DFTTS_SPEAK_ERROR_THREADCOULDNOTCREATE,
	DFTTS_SPEAK_ERROR_BADNVFILE,
	DFTTS_SPEAK_ERROR_NOAUDIODRIVER,
	DFTTS_SPEAK_ERROR_DICTNOTFOUND,
	DFTTS_SPEAK_ERROR_ALREADYPLAYING,
	DFTTS_SPEAK_ERROR_AUDIOFORMATNOTSUPPORTED,
	DFTTS_SPEAK_ERROR_XML_INVALID,
	DFTTS_SPEAK_ERROR_WL_INVALID,
	DFTTS_SPEAK_ERROR_INVALIDPHONESET,
	DFTTS_SPEAK_ERROR_INVALIDPHONEME,
	DFTTS_SPEAK_ERROR_MSGQ_CREATEFAILED,
	DFTTS_SPEAK_ERROR_MSGQ_ALREADYEXISTS,
	DFTTS_SPEAK_ERROR_MSGQ_NOTFOUND,
	DFTTS_SPEAK_ERROR_MSGQ_INVALIDOP,
	DFTTS_SPEAK_ERROR_MSGQ_NOTOPEN,
	DFTTS_SPEAK_ERROR_MSGQ_LOCKFAILED,
	DFTTS_SPEAK_ERROR_MSGQ_ABANDONED,
	DFTTS_SPEAK_ERROR_MSGQ_OPENFAILED,
	DFTTS_SPEAK_ERROR_OTHER
} DFTTSSpeakReturnValue;


typedef enum DFTTSPauseReturnValue
{
	DFTTS_PAUSE_SUCCESS,
	DFTTS_PAUSE_ERROR_UNIMPLEMENTED,
	DFTTS_PAUSE_ERROR_INTERNAL,
	DFTTS_PAUSE_ERROR_INVALID_PARAM,
	DFTTS_PAUSE_ERROR_INVALID_POINTER,
	DFTTS_PAUSE_ERROR_OBJECT_NOT_FOUND,
	DFTTS_PAUSE_ERROR_UNKNOWN_ENCODING,
	DFTTS_PAUSE_ERROR_INTERRUPTED,
	DFTTS_PAUSE_ERROR_INVALID_VOICE,
	DFTTS_PAUSE_ERROR_WRONG_EVENT,
	DFTTS_PAUSE_ERROR_ENGINE_INUSE,
	DFTTS_PAUSE_ERROR_NETWORK_ERROR,
	DFTTS_PAUSE_ERROR_INVALID_KEY,
	DFTTS_PAUSE_ERROR_QUEUE_FULL,
	DFTTS_PAUSE_ERROR_TOKEN_TIMEOUT,
	DFTTS_PAUSE_ERROR_OTHER

} DFTTSPauseReturnValue;


typedef enum DFTTSResumeReturnValue
{
	DFTTS_RESUME_SUCCESS,
	DFTTS_RESUME_ERROR_UNIMPLEMENTED,
	DFTTS_RESUME_ERROR_INTERNAL,
	DFTTS_RESUME_ERROR_INVALID_PARAM,
	DFTTS_RESUME_ERROR_INVALID_POINTER,
	DFTTS_RESUME_ERROR_OBJECT_NOT_FOUND,
	DFTTS_RESUME_ERROR_UNKNOWN_ENCODING,
	DFTTS_RESUME_ERROR_INTERRUPTED,
	DFTTS_RESUME_ERROR_INVALID_VOICE,
	DFTTS_RESUME_ERROR_WRONG_EVENT,
	DFTTS_RESUME_ERROR_ENGINE_INUSE,
	DFTTS_RESUME_ERROR_NETWORK_ERROR,
	DFTTS_RESUME_ERROR_INVALID_KEY,
	DFTTS_RESUME_ERROR_QUEUE_FULL,
	DFTTS_RESUME_ERROR_TOKEN_TIMEOUT,
	DFTTS_RESUME_ERROR_FAILED,
	DFTTS_RESUME_ERROR_INVALIDARG,
	DFTTS_RESUME_ERROR_OUTOFMEMORY,
	DFTTS_RESUME_ERROR_NOTIMPL,
	DFTTS_RESUME_ERROR_ABORT,
	DFTTS_RESUME_ERROR_UNKNOWN,
	DFTTS_RESUME_ERROR_BADHANDLE,
	DFTTS_RESUME_ERROR_EXCEPTION,
	DFTTS_RESUME_ERROR_EMPTY,
	DFTTS_RESUME_ERROR_FULL,
	DFTTS_RESUME_ERROR_INVALIDSTATE,
	DFTTS_RESUME_ERROR_BADVERSION,
	DFTTS_RESUME_ERROR_INSUFFICIENT_BUFFER,
	DFTTS_RESUME_ERROR_UNSUPPORTED,
	DFTTS_RESUME_ERROR_NOLICENSE,
	DFTTS_RESUME_ERROR_CREATECHILDPROCESS_FAILED,
	DFTTS_RESUME_ERROR_NOENVIRONMENTPATH,
	DFTTS_RESUME_ERROR_TIMEOUT,
	DFTTS_RESUME_ERROR_OUTOFRESOURCES,
	DFTTS_RESUME_ERROR_NOVOICES,
	DFTTS_RESUME_ERROR_CREATEFAIL,
	DFTTS_RESUME_ERROR_CONNECTFAIL,
	DFTTS_RESUME_ERROR_BINDFAIL,
	DFTTS_RESUME_ERROR_LISTENFAIL,
	DFTTS_RESUME_ERROR_CONNECTIONCLOSED,
	DFTTS_RESUME_ERROR_ACCEPTFAIL,
	DFTTS_RESUME_ERROR_SOCKETTIMEOUT,
	DFTTS_RESUME_ERROR_SOCKETERROR,
	DFTTS_RESUME_ERROR_NOMORESERVERS,
	DFTTS_RESUME_ERROR_SOCKET_EWOULDBLOCK,
	DFTTS_RESUME_ERROR_SOCKET_EINPROGRESS,
	DFTTS_RESUME_ERROR_SOCKET_EALREADY,
	DFTTS_RESUME_ERROR_SOCKET_ENOTSOCK,
	DFTTS_RESUME_ERROR_SOCKET_EDESTADDRREQ,
	DFTTS_RESUME_ERROR_SOCKET_EMSGSIZE,
	DFTTS_RESUME_ERROR_SOCKET_EPROTOTYPE,
	DFTTS_RESUME_ERROR_SOCKET_ENOPROTOOPT,
	DFTTS_RESUME_ERROR_SOCKET_EPROTONOSUPPORT,
	DFTTS_RESUME_ERROR_SOCKET_ESOCKTNOSUPPORT,
	DFTTS_RESUME_ERROR_SOCKET_EOPNOTSUPP,
	DFTTS_RESUME_ERROR_SOCKET_EPFNOSUPPORT,
	DFTTS_RESUME_ERROR_SOCKET_EAFNOSUPPORT,
	DFTTS_RESUME_ERROR_SOCKET_EADDRINUSE,
	DFTTS_RESUME_ERROR_SOCKET_EADDRNOTAVAIL,
	DFTTS_RESUME_ERROR_SOCKET_ENETDOWN,
	DFTTS_RESUME_ERROR_SOCKET_ENETUNREACH,
	DFTTS_RESUME_ERROR_SOCKET_ENETRESET,
	DFTTS_RESUME_ERROR_SOCKET_ECONNABORTED,
	DFTTS_RESUME_ERROR_SOCKET_ECONNRESET,
	DFTTS_RESUME_ERROR_SOCKET_ENOBUFS,
	DFTTS_RESUME_ERROR_SOCKET_EISCONN,
	DFTTS_RESUME_ERROR_SOCKET_ENOTCONN,
	DFTTS_RESUME_ERROR_SOCKET_ESHUTDOWN,
	DFTTS_RESUME_ERROR_SOCKET_ETOOMANYREFS,
	DFTTS_RESUME_ERROR_SOCKET_ECONNREFUSED,
	DFTTS_RESUME_ERROR_SOCKET_ELOOP,
	DFTTS_RESUME_ERROR_SOCKET_ENAMETOOLONG,
	DFTTS_RESUME_ERROR_SOCKET_EHOSTDOWN,
	DFTTS_RESUME_ERROR_SOCKET_EHOSTUNREACH,
	DFTTS_RESUME_ERROR_SOCKET_ENOTEMPTY,
	DFTTS_RESUME_ERROR_SOCKET_EPROCLIM,
	DFTTS_RESUME_ERROR_THREADSTARTED,
	DFTTS_RESUME_ERROR_THREADNOTSTARTED,
	DFTTS_RESUME_ERROR_THREADCOULDNOTCREATE,
	DFTTS_RESUME_ERROR_BADNVFILE,
	DFTTS_RESUME_ERROR_NOAUDIODRIVER,
	DFTTS_RESUME_ERROR_DICTNOTFOUND,
	DFTTS_RESUME_ERROR_ALREADYPLAYING,
	DFTTS_RESUME_ERROR_AUDIOFORMATNOTSUPPORTED,
	DFTTS_RESUME_ERROR_XML_INVALID,
	DFTTS_RESUME_ERROR_WL_INVALID,
	DFTTS_RESUME_ERROR_INVALIDPHONESET,
	DFTTS_RESUME_ERROR_INVALIDPHONEME,
	DFTTS_RESUME_ERROR_MSGQ_CREATEFAILED,
	DFTTS_RESUME_ERROR_MSGQ_ALREADYEXISTS,
	DFTTS_RESUME_ERROR_MSGQ_NOTFOUND,
	DFTTS_RESUME_ERROR_MSGQ_INVALIDOP,
	DFTTS_RESUME_ERROR_MSGQ_NOTOPEN,
	DFTTS_RESUME_ERROR_MSGQ_LOCKFAILED,
	DFTTS_RESUME_ERROR_MSGQ_ABANDONED,
	DFTTS_RESUME_ERROR_MSGQ_OPENFAILED,
	DFTTS_RESUME_ERROR_NOTHING_TO_RESUME,
	DFTTS_RESUME_ERROR_OTHER

} DFTTSResumeReturnValue;


typedef enum DFTTSStopReturnValue
{
	DFTTS_STOP_SUCCESS,
	DFTTS_STOP_ERROR_INVALID_POINTER,
	DFTTS_STOP_ERROR_INVALID_ARG,
	DFTTS_STOP_ERROR_OUT_OF_MEMORY,
	DFTTS_STOP_ERROR_INVALID_FLAGS,
	DFTTS_STOP_ERROR_ENGINE_INUSE,
	DFTTS_STOP_ERROR_OTHER

} DFTTSStopReturnValue;


typedef enum DFTTSExportReturnValue
{
	DFTTS_EXPORT_SUCCESS,
	DFTTS_EXPORT_ERROR_FORMAT_NOT_SUPPORTED,
	DFTTS_EXPORT_ERROR_CHANNEL_MEM_FAIL,
	DFTTS_EXPORT_ERROR_TEXT_NULL,
	DFTTS_EXPORT_ERROR_TEXT_ZERO_LEN,
	DFTTS_EXPORT_ERROR_DB_NOT_LOADED,
	DFTTS_EXPORT_ERROR_GEN_FILE_FAIL,
	DFTTS_EXPORT_ERROR_BUFFER_NULL,
	DFTTS_EXPORT_ERROR_THREAD_IN_USE,
	DFTTS_EXPORT_ERROR_UNIMPLEMENTED,
	DFTTS_EXPORT_ERROR_INTERNAL,
	DFTTS_EXPORT_ERROR_INVALID_PARAM,
	DFTTS_EXPORT_ERROR_INVALID_POINTER,
	DFTTS_EXPORT_ERROR_OBJECT_NOT_FOUND,
	DFTTS_EXPORT_ERROR_UNKNOWN_ENCODING,
	DFTTS_EXPORT_ERROR_INTERRUPTED,
	DFTTS_EXPORT_ERROR_INVALID_VOICE,
	DFTTS_EXPORT_ERROR_WRONG_EVENT,
	DFTTS_EXPORT_ERROR_ENGINE_INUSE,
	DFTTS_EXPORT_ERROR_NETWORK_ERROR,
	DFTTS_EXPORT_ERROR_INVALID_KEY,
	DFTTS_EXPORT_ERROR_QUEUE_FULL,
	DFTTS_EXPORT_ERROR_TOKEN_TIMEOUT,
	DFTTS_EXPORT_ERROR_FAILED,
	DFTTS_EXPORT_ERROR_INVALIDARG,
	DFTTS_EXPORT_ERROR_OUTOFMEMORY,
	DFTTS_EXPORT_ERROR_NOTIMPL,
	DFTTS_EXPORT_ERROR_ABORT,
	DFTTS_EXPORT_ERROR_UNKNOWN,
	DFTTS_EXPORT_ERROR_BADHANDLE,
	DFTTS_EXPORT_ERROR_EXCEPTION,
	DFTTS_EXPORT_ERROR_EMPTY,
	DFTTS_EXPORT_ERROR_FULL,
	DFTTS_EXPORT_ERROR_INVALIDSTATE,
	DFTTS_EXPORT_ERROR_BADVERSION,
	DFTTS_EXPORT_ERROR_INSUFFICIENT_BUFFER,
	DFTTS_EXPORT_ERROR_UNSUPPORTED,
	DFTTS_EXPORT_ERROR_NOLICENSE,
	DFTTS_EXPORT_ERROR_CREATECHILDPROCESS_FAILED,
	DFTTS_EXPORT_ERROR_NOENVIRONMENTPATH,
	DFTTS_EXPORT_ERROR_TIMEOUT,
	DFTTS_EXPORT_ERROR_OUTOFRESOURCES,
	DFTTS_EXPORT_ERROR_NOVOICES,
	DFTTS_EXPORT_ERROR_CREATEFAIL,
	DFTTS_EXPORT_ERROR_CONNECTFAIL,
	DFTTS_EXPORT_ERROR_BINDFAIL,
	DFTTS_EXPORT_ERROR_LISTENFAIL,
	DFTTS_EXPORT_ERROR_CONNECTIONCLOSED,
	DFTTS_EXPORT_ERROR_ACCEPTFAIL,
	DFTTS_EXPORT_ERROR_SOCKETTIMEOUT,
	DFTTS_EXPORT_ERROR_SOCKETERROR,
	DFTTS_EXPORT_ERROR_NOMORESERVERS,
	DFTTS_EXPORT_ERROR_SOCKET_EWOULDBLOCK,
	DFTTS_EXPORT_ERROR_SOCKET_EINPROGRESS,
	DFTTS_EXPORT_ERROR_SOCKET_EALREADY,
	DFTTS_EXPORT_ERROR_SOCKET_ENOTSOCK,
	DFTTS_EXPORT_ERROR_SOCKET_EDESTADDRREQ,
	DFTTS_EXPORT_ERROR_SOCKET_EMSGSIZE,
	DFTTS_EXPORT_ERROR_SOCKET_EPROTOTYPE,
	DFTTS_EXPORT_ERROR_SOCKET_ENOPROTOOPT,
	DFTTS_EXPORT_ERROR_SOCKET_EPROTONOSUPPORT,
	DFTTS_EXPORT_ERROR_SOCKET_ESOCKTNOSUPPORT,
	DFTTS_EXPORT_ERROR_SOCKET_EOPNOTSUPP,
	DFTTS_EXPORT_ERROR_SOCKET_EPFNOSUPPORT,
	DFTTS_EXPORT_ERROR_SOCKET_EAFNOSUPPORT,
	DFTTS_EXPORT_ERROR_SOCKET_EADDRINUSE,
	DFTTS_EXPORT_ERROR_SOCKET_EADDRNOTAVAIL,
	DFTTS_EXPORT_ERROR_SOCKET_ENETDOWN,
	DFTTS_EXPORT_ERROR_SOCKET_ENETUNREACH,
	DFTTS_EXPORT_ERROR_SOCKET_ENETRESET,
	DFTTS_EXPORT_ERROR_SOCKET_ECONNABORTED,
	DFTTS_EXPORT_ERROR_SOCKET_ECONNRESET,
	DFTTS_EXPORT_ERROR_SOCKET_ENOBUFS,
	DFTTS_EXPORT_ERROR_SOCKET_EISCONN,
	DFTTS_EXPORT_ERROR_SOCKET_ENOTCONN,
	DFTTS_EXPORT_ERROR_SOCKET_ESHUTDOWN,
	DFTTS_EXPORT_ERROR_SOCKET_ETOOMANYREFS,
	DFTTS_EXPORT_ERROR_SOCKET_ECONNREFUSED,
	DFTTS_EXPORT_ERROR_SOCKET_ELOOP,
	DFTTS_EXPORT_ERROR_SOCKET_ENAMETOOLONG,
	DFTTS_EXPORT_ERROR_SOCKET_EHOSTDOWN,
	DFTTS_EXPORT_ERROR_SOCKET_EHOSTUNREACH,
	DFTTS_EXPORT_ERROR_SOCKET_ENOTEMPTY,
	DFTTS_EXPORT_ERROR_SOCKET_EPROCLIM,
	DFTTS_EXPORT_ERROR_THREADSTARTED,
	DFTTS_EXPORT_ERROR_THREADNOTSTARTED,
	DFTTS_EXPORT_ERROR_THREADCOULDNOTCREATE,
	DFTTS_EXPORT_ERROR_BADNVFILE,
	DFTTS_EXPORT_ERROR_NOAUDIODRIVER,
	DFTTS_EXPORT_ERROR_DICTNOTFOUND,
	DFTTS_EXPORT_ERROR_ALREADYPLAYING,
	DFTTS_EXPORT_ERROR_AUDIOFORMATNOTSUPPORTED,
	DFTTS_EXPORT_ERROR_XML_INVALID,
	DFTTS_EXPORT_ERROR_WL_INVALID,
	DFTTS_EXPORT_ERROR_INVALIDPHONESET,
	DFTTS_EXPORT_ERROR_INVALIDPHONEME,
	DFTTS_EXPORT_ERROR_MSGQ_CREATEFAILED,
	DFTTS_EXPORT_ERROR_MSGQ_ALREADYEXISTS,
	DFTTS_EXPORT_ERROR_MSGQ_NOTFOUND,
	DFTTS_EXPORT_ERROR_MSGQ_INVALIDOP,
	DFTTS_EXPORT_ERROR_MSGQ_NOTOPEN,
	DFTTS_EXPORT_ERROR_MSGQ_LOCKFAILED,
	DFTTS_EXPORT_ERROR_MSGQ_ABANDONED,
	DFTTS_EXPORT_ERROR_MSGQ_OPENFAILED,
	DFTTS_EXPORT_ERROR_OTHER

} DFTTSExportReturnValue;


typedef enum DFTTSParamInfoReturnValue
{
	DFTTS_PARAM_INFO_SUCCESS,
	DFTTS_PARAM_INFO_ERROR_ENGINE_NOT_SUPPORTED
} DFTTSParamInfoReturnValue;


typedef enum DFTTSParamType
{


	DFTTS_BUILD_DATE,
	DFTTS_VERIFY_CODE,
	DFTTS_MAX_CHANNEL,
	DFTTS_DB_DIRECTORY,
	DFTTS_LOAD_SUCCESS_CODE,
	DFTTS_MAX_SPEAKER,
	DFTTS_DEF_SPEAKER,
	DFTTS_CODEPAGE,
	DFTTS_DB_ACCESS_MODE,
	DFTTS_FIXED_POINT_SUPPORT,
	DFTTS_SAMPLING_FREQUENCY,
	DFTTS_MAX_PITCH_RATE,
	DFTTS_DEF_PITCH_RATE,
	DFTTS_MIN_PITCH_RATE,
	DFTTS_MAX_SPEED_RATE,
	DFTTS_DEF_SPEED_RATE,
	DFTTS_MIN_SPEED_RATE,
	DFTTS_MAX_VOLUME,
	DFTTS_DEF_VOLUME,
	DFTTS_MIN_VOLUME,
	DFTTS_MAX_SENT_PAUSE,
	DFTTS_DEF_SENT_PAUSE,
	DFTTS_MIN_SENT_PAUSE	
			
} DFTTSParamType;


/*(v 2.0.0)*/
typedef enum DFTTSVoiceInfoReturnValue
{

	GET_DFTTS_VI_SUCCESS,
	GET_DFTTS_VI_NO_MORE_ITEMS,
	GET_DFTTS_VI_ERROR_BUFFER_TOO_SMALL,
	GET_DFTTS_VI_ERROR_OTHER

} DFTTSVoiceInfoReturnValue;


/*Cepstral voice engine and others MUST use this struct for the export (v 2.0.0)*/
typedef struct DFTTSComplexExportData
{

	char* AudioEncoding; /*"pcm16" 16bit "pcm8" 8bit.*/

	int AudioSamplingRate; /*8000 Hz, 16000 Hz etc.*/
		
	int AudioChannels; /*mono-1,stereo-2*/

} DFTTSComplexExportData;


/*(v 2.0.0) modified v 3.5.0*/
typedef struct InitDFTTSEngineReturnValueEx
{
	DFTTSVoiceEngineType vet[NUM_ENGINE_INITIALIZATIONS];
	
	InitDFTTSEngineReturnValue ert[NUM_ENGINE_INITIALIZATIONS];

	void copy( DFTTSVoiceEngineType* psiLoadedEngines, 
		InitDFTTSEngineReturnValue* psiLoadedEnginesReturnValues)
	{
		size_t i = 0;

		for( ;i<NUM_ENGINE_INITIALIZATIONS; ++i )
		{
			vet[i] = psiLoadedEngines[i];
			
			ert[i] = psiLoadedEnginesReturnValues[i];
		}

	}
} InitDFTTSEngineReturnValueEx;


/*(v 2.0.0)*/
typedef struct DFTTSVoiceInfo
{
	DFTTSVoiceEngineType vet;

	char* szVoiceName;

	int iVoiceID;

	unsigned short lang;

} DFTTSVoiceInfo;


/*(v 2.0.0)*/
typedef struct DFTTSVoiceInfoCollection
{
	DFTTSVoiceInfoCollection* pViNext;

	DFTTSVoiceInfo* pViValue;

} DFTTSVoiceInfoCollection;


typedef void DFTTSOnWordCallBack( int start, int end );

typedef void DFTTSOnExportCallBack( int start, int end );

#endif //_DFTTS_VAL_H_
