///****************************************************************************
//// Name:        DFTTSSampleObjectiveC with DFTTS Desktop SDK v 3.5.0
//// Purpose:
//// Author:      Digital Future
//// Modified by:
//// Created:     07/12/2008
//// RCS-ID:
//// Copyright:   (C) Digital Future 2008. All rights reserved.
//// License:     see license document
//***************************************************************************/

#import "DFTTSSampleObjC.h"
#include <string>
#include <vector>
using namespace std;


//Let's use this vector for the sake of our example
static vector<DFTTSVoiceInfo*> g_vVi;

void callBackOnWord( int start, int end )
{
	//MACOSXSPMAN ALSO USES THIS CALLBACK WHEN EXPORTING. 
	char szMsg[256];
	
	sprintf( szMsg, "Start character: %d. End character: %d.\n", start, end );

	printf( szMsg );

}

void callBackOnExport( int start, int end )
{
	
	//MACOSXSPMAN: USE callBackOnWord
	char szMsg[256];
	
	sprintf( szMsg, "Start exp. character: %d. End exp. character: %d.\n", start, end );

	printf( szMsg );


}


@implementation DFTTSSampleObjC

- (void)awakeFromNib
{


	//This is how to list all installed supported voices
	
	char szVoiceName[1024];
	
	int iVoiceNameLen = 0;
	
	DFTTSVoiceEngineType vet = NOENGINE;
	
	unsigned short lang = LANG_SUBLANG_NEUTRAL;
	
	int iVoiceID = -1;
		
	int z=0;
	
	[popupVoiceButton removeItemAtIndex:0];
	
	for( ; ; z++ )
	{
		DFTTSVoiceInfoReturnValue result = GetDFTTSVoice(
														 z, &vet, szVoiceName, &iVoiceNameLen,
														 &iVoiceID, &lang );
#if _DEBUG
		switch( result )
		{
			case GET_DFTTS_VI_SUCCESS:
				printf( "GET_DFTTS_VI_SUCCESS\n" );
				break;
			case GET_DFTTS_VI_NO_MORE_ITEMS:
				printf(  "GET_DFTTS_VI_NO_MORE_ITEMS" );
				break;
			case GET_DFTTS_VI_ERROR_BUFFER_TOO_SMALL:
				printf(  "GET_DFTTS_VI_ERROR_BUFFER_TOO_SMALL" );
				break;
			case GET_DFTTS_VI_ERROR_OTHER:
				printf(  "GET_DFTTS_VI_ERROR_OTHER" );
				break;
		}
		
#endif
		
		if( result == GET_DFTTS_VI_SUCCESS )
		{
			
#if _DEBUG
			
			string msg = string("Voice Name: ") + string(szVoiceName) + string("\n");
			
			if( vet == NEOSPEECHVOICETEXT )
				msg += string("Engine: NEOSPEECHVOICETEXT.\n");
			else if( vet == CEPSTRAL )
				msg += string("Engine: CEPSTRAL.\n");
			else if( vet == MSSAPI )
				msg += string("Engine: MSSAPI.\n");
			else if( vet == ATTNV )
				msg += string("Engine: ATTNV (Internal use only - use MSSAPI).\n");
			else if( vet == MACOSXSPMAN )
				msg += string("Engine: MACOSXSPMAN.\n");	
			else
				msg += string("Engine: NO OFFICIALLY SUPPORTED.\n");
			
			
			printf( msg.c_str() );
			
#endif

			if( strstr(szVoiceName,"Cepstral") == NULL ) //!Do not use Cepstral with MACOSXSPMAN. It will crash! Use it directly with voice engine type CEPSTRAL
			{
			
				DFTTSVoiceInfo* vi = new DFTTSVoiceInfo;
				
				vi->iVoiceID = iVoiceID;
				vi->lang = lang;
				vi->szVoiceName = new char[strlen(szVoiceName)+1];
				strcpy( vi->szVoiceName, szVoiceName );
				vi->vet = vet;
				
				g_vVi.push_back( vi );		
				
				//Produce a NSString and add to menu					
				
				NSString* nsString = [[NSString alloc] initWithCString:szVoiceName]; 
								
				[popupVoiceButton addItemWithTitle:nsString];
								
			}
			
		}
		else
		{
			break;
		}
		
		
	}



} 

- (void)onAppExit:(NSNotification *)notification
{  
	
	//IMPORTANT!
	//Stop voice if still speaking
	//Clean the vector data
	//Uninitialize the SDK	
	
	if( isSpeaking )
	{			
		int y = [popupVoiceButton indexOfSelectedItem]; 
		
		DFTTSStop(g_vVi[y]->vet,g_vVi[y]->lang);
		
	}				
	
	vector<DFTTSVoiceInfo*>::const_iterator it;
	
	for( it=g_vVi.begin();it!=g_vVi.end();++it )
	{
		delete[] (*it)->szVoiceName;
		
		delete *it;
		
	}
	
	UninitDFTTSEngine();
	
	printf("Speech SDK Memory Released!\n");
	
	
}



- (id)init
{
	
		
	// listen for app termination notifications
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(onAppExit:) name:NSApplicationWillTerminateNotification object:NSApp];
	
	//Set flags
	
	isPaused = false;
	
	isSpeaking = false;
	
	//Initilize voices and set the callbacks
	
	//Set the OnWord callback function
	
	SetDFTTSOnWordCallBack( callBackOnWord );
				
	//Set the OnExport callback function
				
	SetDFTTSOnExportCallBack( callBackOnExport );
	
				
	InitDFTTSEngineReturnValueEx* initresult = InitDFTTSEngineEx( 0,0,0 );
	
				
	/****************************************************

	initresult is an pointer to InitDFTTSEngineReturnValueEx with 2 array members.
	
	NEOSPEECHVOICETEXT (NOT SUPPORTED BY MAC OS X)

	//NEOSPEECHVOICETEXT ENGLISH 
	initresult.vet[0] = NEOSPEECHVOICETEXT; //KATE
	initresult.vet[1] = NEOSPEECHVOICETEXT; //PAUL

	//NEOSPEECHVOICETEXT JAPANESE
	initresult.vet[2] = NEOSPEECHVOICETEXT; //MIYU
	initresult.vet[3] = NEOSPEECHVOICETEXT; //SHOW
	initresult.vet[4] = NEOSPEECHVOICETEXT; //MISAKI

	//NEOSPEECHVOICETEXT CHINESE
	initresult.vet[5] = NEOSPEECHVOICETEXT; //LILY
	initresult.vet[6] = NEOSPEECHVOICETEXT; //WANG

	//NEOSPEECHVOICETEXT KOREAN
	initresult.vet[7] = NEOSPEECHVOICETEXT; //JUNWOO
	initresult.vet[8] = NEOSPEECHVOICETEXT; //SUJIN
	initresult.vet[9] = NEOSPEECHVOICETEXT; //YUMI
	initresult.vet[10] = NEOSPEECHVOICETEXT; //GYURI
	initresult.vet[11] = NEOSPEECHVOICETEXT; //DAYOUNG

	//CEPSTRAL
	initresult.vet[12] = CEPSTRAL;

	//AT&T NV (NOT SUPPORTED BY MAC OS X)
	initresult.vet[13] = ATTNV; 
				
	//MAC OS X SPMAN
	initresult.vet[14] = MACOSXSPMAN; 
				
	//MICROSOFT SAPI (NOT SUPPORTED BY MAC OS X)
	initresult.vet[15] = MSSAPI; 				

	ert memebers are of type InitDFTTSEngineReturnValue
				
	(NOT SUPPORTED BY MAC OS X)
	initresult.ert[0] - error code for NeoSpeech Kate
	initresult.ert[1] - error code for NeoSpeech Paul
	initresult.ert[2] - error code for NeoSpeech Miyu
	initresult.ert[3] - error code for NeoSpeech Show
	initresult.ert[4] - error code for NeoSpeech Misaki
	initresult.ert[5] - error code for NeoSpeech Lily
	initresult.ert[6] - error code for NeoSpeech Wang
	initresult.ert[7] - error code for NeoSpeech Junwoo
	initresult.ert[8] - error code for NeoSpeech Sujin
	initresult.ert[9] - error code for NeoSpeech Yumi
	initresult.ert[10] - error code for NeoSpeech Gyuri
	initresult.ert[11] - error code for NeoSpeech Dayoung
				
	initresult.ert[12] - error code for the whole Cepstral engine
				
	(NOT SUPPORTED BY MAC OS X)
	initresult.ert[13] - error code for the whole AT&T NV engine
					
	initresult.ert[14] - error code for the whole MAC OS X SPMAN
				
	(NOT SUPPORTED BY MAC OS X)				  				  
	initresult.ert[15] - error code for the whole MS SAPI

	*****************************************************/
	
	
	if( initresult->ert[12] != INIT_DFTTS_ENGINE_SUCCESS )
	{
		
		char szErrNo[2];
		
		sprintf( szErrNo, "%d", (short)initresult->ert[12] );
		
		printf("CEPSTRAL engine initialization error: ");
		
		printf( szErrNo );
		
		printf( ".\nThe voice or engine may not be installed.\n" );
		
		
	}
	else if( initresult->ert[14] != INIT_DFTTS_ENGINE_SUCCESS )
	{
		
		char szErrNo[2];
		
		sprintf( szErrNo, "%d", (short)initresult->ert[14] );
		
		printf("MAC OS X SPEECH MANAGER initialization error: ");
		
		printf( szErrNo );
		
		printf( ".\nReview the error code reason.\n" );
		
		
	}	
	
	
	LoadDFTTSUserDictReturnValue dictreturn = LOAD_USER_DICT_SUCCESS;
	
	//This is how to load a dictionary for the Cepstral provider (the dictionary is loaded 
	//by voice, the dictionary number, dict name, dict content do NOT matter.)
	//See folder DictionarySystems for more info on phonemes

	/*dictreturn = LoadDFTTSUserDict( -1, NULL,
						"cepstral_dictionary.txt",
						CEPSTRAL, LANG_SUBLANG_NEUTRAL, "David", NULL );*/	
	
	//MACOSXSPMAN dictionaries: NOT SUPPORTED ( DEPRECATED AND POORLY DOCUMENTED BY APPLE )
	
	if( dictreturn != LOAD_USER_DICT_SUCCESS )
	{
		
		char szMsg[256];
		
		sprintf( szMsg, "Dictionary load error: %d\n", (short)dictreturn );
		
		printf(szMsg);
		
	}					


	
	return self;
}



- (IBAction)onSpeak:(id)sender 
{

		NSString* nsValue = [[NSString alloc] init]; 
		
		nsValue = [textBox stringValue];
		
		char* value = (char*)[nsValue cStringUsingEncoding:NSMacOSRomanStringEncoding];
			
		
		//Get the menu selected idex (make it 0-based)
		int y = [popupVoiceButton indexOfSelectedItem]; 
		
														
		DFTTSSpeakReturnValue result = DFTTSSpeak( 0,g_vVi[y]->vet,g_vVi[y]->szVoiceName,g_vVi[y]->iVoiceID,
					g_vVi[y]->lang,value,-1,-1,-1,-1,
					1,DFTTS_TEXT_TYPE_XML,-1 );
	
					
		if( result != DFTTS_SPEAK_SUCCESS )
		{
			char szMsg[256];
			
			sprintf( szMsg, "SDK Speak error: %d\n", (short)result );
			
			printf(szMsg);
			
		}
		else
			isSpeaking = true;
			
}

- (IBAction)onPauseResume:(id)sender 
{
	
	int y = [popupVoiceButton indexOfSelectedItem]; 
	
	if( isPaused )
	{
		
		DFTTSResumeReturnValue result = DFTTSResume(g_vVi[y]->vet,g_vVi[y]->lang);
		
		if( result != DFTTS_RESUME_SUCCESS )
		{
			char szMsg[256];
			
			sprintf( szMsg, "SDK Resume error: %d\n", (short)result );
			
			printf(szMsg);
			
		}
		else
			isPaused = false;
		
		
	}
	else if( !isPaused )
	{
		DFTTSPauseReturnValue result = DFTTSPause(g_vVi[y]->vet,g_vVi[y]->lang);
		
		if( result != DFTTS_PAUSE_SUCCESS )
		{
			char szMsg[256];
			
			sprintf( szMsg, "SDK Pause error: %d\n", (short)result );
			
			printf(szMsg);
			
		}
		else
			isPaused = true;
		
	}			
	
	
}

- (IBAction)onStop:(id)sender 
{
	
	int y = [popupVoiceButton indexOfSelectedItem]; 
	
	DFTTSStopReturnValue result = DFTTSStop(g_vVi[y]->vet,g_vVi[y]->lang);
	
	if( result != DFTTS_STOP_SUCCESS )
	{
		char szMsg[256];
		
		sprintf( szMsg, "SDK Stop error: %d\n", (short)result );
		
		printf(szMsg);
		
	}
	else
		isSpeaking = false;  

}

- (IBAction)onExport:(id)sender 
{
	
	NSString* nsValue = [[NSString alloc] init]; 
	
	nsValue = [textBox stringValue];
	
	char* value = (char*)[nsValue cStringUsingEncoding:NSMacOSRomanStringEncoding];  
	
	//Get the menu selected idex (make is 0-based)
	int y = [popupVoiceButton indexOfSelectedItem]; 
	
	/*!!! MACOSXSPMAN ONLY AIFF FILE SUPPORT. FORMAT ARGS WILL BE IFNORED !!!*/	
	char* filePath = 0;
	
	if( g_vVi[y]->vet == MACOSXSPMAN )
		filePath = "test.aiff";
	else
		filePath = "test.wav";		
					
	
	DFTTSExportReturnValue result = DFTTSExportToFileEx( g_vVi[y]->vet,g_vVi[y]->szVoiceName,g_vVi[y]->iVoiceID,
														 g_vVi[y]->lang,value,
														 -1,-1,-1,-1,1,DFTTS_TEXT_TYPE_XML,filePath, 0, "pcm16",16000,2 );								 
		
	if( result != DFTTS_EXPORT_SUCCESS )
	{
		char szMsg[256];
		
		sprintf( szMsg, "SDK Export error: %d\n", (short)result );
		
		printf(szMsg);
		
	}				
}


@end
